function SceneMain(options)
{
	this.options = options;
    this.prevScene = [];
    this.selfState = {};
    this.currentScene = {};
    this.user = {nick: "", uuid: "", iplex_plus: null, iplex_xero: null};
}

SceneMain.prototype.initialize = function ()
{
	alert("SceneMain.initialize()");
	
	var caller = this;
	
	var onAccountData = function (status)
	{
		caller.sendRequestForData(caller.selfState);
	};
	
	var onUserAuthentication = function (status)
	{
		// status ERROR, FALSE, NOUSER, INVALID_CREDENTIALS - do nothing 
		if (status == "TRUE")
		{
			caller.getAccountData(onAccountData);
		}
		else
		{
			caller.sendRequestForData(caller.selfState);
		}
	};
	
	var onGeoBlockCheck = function (status)
	{
		if (status == "TRUE")
		{
			caller.authenticateUser(onUserAuthentication);
		}
	};
	
	var checkConnection = function (callback)
	{
	    if (internetConnectionCheck.connectionAvailable())
	    {
	    	callback();	
	    }
	    else
	    {
	    	setTimeout(function(){checkConnection(callback);}, 1000);
	    }
	};
	
    this.selfState.url = conf.mainFeedUrl;
    this.selfState.caption = "";
    this.selfState.type = "category";
    this.selfState.cursor = 0;
    
    this.helpBar({"return": "Wyjdź"});
    
    checkConnection(function()
    {
    	caller.checkGeoBlock(onGeoBlockCheck);
    });
};

SceneMain.prototype.checkGeoBlock = function (fnCallback, showErrors)
{
	var caller = this;
	
	if (typeof showErrors == "undefined")
	{
		showErrors = true;
	}
	
    geoXHR =  this.getXHRObj("Geoblock");
    geoXHR.sendXHRRequest(conf.geoblockUrl, function (result, respObj)
    {
        if (result)
        {
            var resp = $.parseJSON(respObj.responseText);
            
            if (resp.valid)
            {
            	fnCallback("TRUE");
            }
            else
            {
            	if (showErrors)
            	{
            		caller.showError("Main", "Przepraszamy, nasza biblioteka filmów dostępna jest jedynie dla użytkowników znajdujących się na terenie Polski.<br /><br />Sorry, currently our video library can only be streamed from within Poland.");
            	}
                fnCallback("FALSE");
            }
        }
        else
        {
        	if (showErrors)
        	{
        		caller.showError("Main", "Przepraszamy, wystąpił błąd z połączeniem [0x0].<br />Prosimy spróbować ponownie za chwilę.");
        	}
            fnCallback("ERROR");
        }
    }, null);
};

SceneMain.prototype.authenticateUser = function (fnCallback, showErrors)
{
	if (typeof showErrors == "undefined")
	{
		showErrors = true;
	}
	
	var caller = this;
	
	var onLogin = function (status, response)
	{
		switch (status)
		{
			case "TRUE":
    			caller.user.nick = response.nick;
    			caller.user.uuid = response.uuid;
    			caller.user.iplex_plus =  null;
    			caller.user.iplex_zero =  null;
				break;
				
			case "ERROR":
    			if (showErrors)
    			{
    				caller.showError("AuthenticateUser", "Przepraszamy, wystąpił błąd przy logowaniu użytkownika [0x1x1].<br />Prosimy spróbować ponownie za chwilę.");
    			}
				break;
				
			case "NOUSER":
				break;
				
			case "INVALID_CREDENTIALS":
    			if (showErrors)
    			{
    				caller.showError("AuthenticateUser", "Podany login lub hasło są niepoprawne. Czy chcesz się teraz zalogować? [0x1x0]", {"login": true, "cancel": true});
    			}
				break;
				
			default:
				break;
		}
		
		fnCallback(status);
		
		return true;
	};
	
	IplexAuth.autoLogin(onLogin);
};

SceneMain.prototype.logoutUser = function ()
{
	IplexAuth.logout();
	
	this.user.nick = "";
	this.user.uuid = "";
	this.user.iplex_plus = null;
	this.user.iplex_zero = null;
};

SceneMain.prototype.getUser = function ()
{
	return this.user;
};

SceneMain.prototype.isUserLogged = function ()
{
	var user = this.getUser();
	return (user.uuid == "" ? false : true);
};

SceneMain.prototype.isIplexPlusAvailable = function ()
{
	if (this.isUserLogged())
	{
		return (!this.getUser().iplex_plus || this.getUser().iplex_plus.days < 0 ? false : true);
	}
	else
	{
		return false;
	}
};

SceneMain.prototype.isIplexZeroAvailable = function ()
{
	if (this.isUserLogged())
	{
		return (!this.getUser().iplex_zero || this.getUser().iplex_zero.days < 0 ? false : true);
	}
	else
	{
		return false;
	}
};

SceneMain.prototype.getAccountData = function (fnCallback, showErrors)
{
	if (typeof showErrors == "undefined")
	{
		showErrors = true;
	}
	
	if (!this.isUserLogged())
	{
		fnCallback("NOUSER");
		return true;
	}
	
	var caller = this;
	
    accountDataXHR =  this.getXHRObj("AccountDataRequest");
    accountDataXHR.sendXHRRequest(conf.accountData, function (result, respObj)
    {
        if (result)
        {
    		var response = $.parseJSON(respObj.responseText);
    		
    		if (typeof response.ERROR_CODE != "undefined" && response.ERROR_CODE == "NOT_AUTHENTICATED")
    		{
    			caller.logoutUser();
    			if (showErrors)
    			{
    				caller.showError("GetAccountData", "Nastąpiło wylogowanie użytkownika. Zaloguj się ponownie. [0x2x0]");
    			}
    			fnCallback("FALSE");
    		}
    		else if (typeof response.ERROR_CODE != "undefined")
    		{
    			if (showErrors)
    			{
    				caller.showError("GetAccountData", "Przepraszamy, wystąpił nieznany błąd przy pobieraniu danych użytkownika [0x2x1].<br />Prosimy spróbować ponownie za chwilę.");
    			}
    			fnCallback("ERROR");
    		}
    		else if (typeof response.iplex_plus != "undefined" && typeof response.iplex_zero != "undefined")
    		{
    			caller.user.iplex_plus = response.iplex_plus;
    			caller.user.iplex_zero = response.iplex_zero;
    			fnCallback("TRUE");
    		}
    		else
    		{
    			if (showErrors)
    			{
    				caller.showError("GetAccountData", "Przepraszamy, wystąpił nieznany błąd przy pobieraniu danych użytkownika [0x2x2].<br />Prosimy spróbować ponownie za chwilę.");
    			}
    			fnCallback("ERROR");
    		}
        }
        else
        {
        	if (showErrors)
        	{
        		caller.showError("GetAccountData", "Przepraszamy, wystąpił nieznany błąd przy pobieraniu danych użytkownika [0x2x3].<br />Prosimy spróbować ponownie za chwilę.");
        	}
        	fnCallback("ERROR");
        }
        
    }, this.getUser().uuid);
};

SceneMain.prototype.sendRequestForData = function (newScene, oldScene)
{
//  alert("[URL] " + newScene.url);
    
//  $.each(newScene, function(index, value)
//  {
//      alert("newScene "+index+": "+value);
//  });
//  
//  if (typeof oldScene == "object")
//  {
//      $.each(oldScene, function(index, value)
//      {
//          alert("oldScene "+index+": "+value);
//      });
//  }
	
	if (typeof newScene != "object" || newScene.url == null)
    {
        alert("sendRequestForData: Object expected");
        return false;
    }
    
    this.currentScene = newScene;
    
    if (typeof oldScene == "object")
    {
        this.prevScene.push(oldScene);
    }
    
    if (newScene.type == "category")
    {
        $.sfScene.hide("NavigationMenuMovies");
        $.sfScene.hide("Movie");
        $.sfScene.hide("Player");
        $.sfScene.hide("EnterPromoCode");
        $.sfScene.hide("Login");
        $.sfScene.show("NavigationMenuCategories");
        $.sfScene.show("MoviesPanel");
        $.sfScene.focus("NavigationMenuCategories");
        $.sfScene.get("NavigationMenuCategories").sendRequestForData(newScene);
    }
    else if (newScene.type == "account")
    {
        $.sfScene.hide("NavigationMenuMovies");
        $.sfScene.hide("Movie");
        $.sfScene.hide("Player");
        $.sfScene.hide("EnterPromoCode");
        $.sfScene.hide("Login");
        $.sfScene.show("NavigationMenuCategories");
        $.sfScene.show("MoviesPanel");
        $.sfScene.focus("NavigationMenuCategories");
        $.sfScene.get("NavigationMenuCategories").sendRequestForData(newScene);
    }
    else if (newScene.type == "account_mngmt")
    {
    	if (newScene.url == "appl://login")
    	{
    		$.sfScene.hide("NavigationMenuCategories");
            $.sfScene.hide("NavigationMenuMovies");
            $.sfScene.hide("Movie");
            $.sfScene.hide("Player");
            $.sfScene.hide("MoviesPanel");
            $.sfScene.hide("EnterPromoCode");
            $.sfScene.show("Login");
            $.sfScene.focus("Login");
    	}
    	else if (newScene.url == "appl://logout")
    	{
    		this.logoutUser();
    		this.clearHistory();
    	    this.selfState.url = conf.mainFeedUrl;
    	    this.selfState.caption = "";
    	    this.selfState.type = "category";
    	    this.selfState.cursor = 0;
    	    this.sendRequestForData(this.selfState);
    	    $.sfScene.get("Main").showError("NavigationMenuCategories", "Użytkownik został wylogowany.");
    	}
    	else if (newScene.url == "appl://enter_promo_code_plus")
    	{
    		$.sfScene.hide("NavigationMenuCategories");
            $.sfScene.hide("NavigationMenuMovies");
            $.sfScene.hide("Movie");
            $.sfScene.hide("Player");
            $.sfScene.hide("MoviesPanel");
            $.sfScene.hide("Login");
            $.sfScene.get("EnterPromoCode").mode = "PLUS";
            $.sfScene.show("EnterPromoCode");
            $.sfScene.focus("EnterPromoCode");
    	}
    	else if (newScene.url == "appl://enter_promo_code_zero")
    	{
    		$.sfScene.hide("NavigationMenuCategories");
            $.sfScene.hide("NavigationMenuMovies");
            $.sfScene.hide("Movie");
            $.sfScene.hide("Player");
            $.sfScene.hide("MoviesPanel");
            $.sfScene.hide("Login");
            $.sfScene.get("EnterPromoCode").mode = "ZERO";
            $.sfScene.show("EnterPromoCode");
            $.sfScene.focus("EnterPromoCode");
    	}
    }
    else if (newScene.type == "playlist")
    {
        $.sfScene.hide("NavigationMenuCategories");
        $.sfScene.hide("MoviesPanel");
        $.sfScene.hide("Player");
        $.sfScene.hide("EnterPromoCode");
        $.sfScene.hide("Login");
        $.sfScene.show("NavigationMenuMovies");
        $.sfScene.show("Movie");
        $.sfScene.focus("NavigationMenuMovies");
        $.sfScene.get("NavigationMenuMovies").sendRequestForData(newScene);
    }
    else if (newScene.type == "video")
    {
        $.sfScene.hide("NavigationMenuMovies");
        $.sfScene.hide("Movie");
        $.sfScene.hide("NavigationMenuCategories");
        $.sfScene.hide("MoviesPanel");
        $.sfScene.hide("EnterPromoCode");
        $.sfScene.hide("Login");
        $.sfScene.show("Player");
        $.sfScene.focus("Player");
        $.sfScene.get("Player").sendRequestForData(newScene);
    }
    else if (newScene.type == "movie_card")
    {
        $.sfScene.get("Movie").sendRequestForData(newScene);
    }
    else if (newScene.type == "series_card")
    {
        $.sfScene.get("Movie").sendRequestForData(newScene);
    }
    else
    {
        alert("sendRequestForData: Unsuported object type="+newScene.type);
        return false;
    }
    
    return true;
};

SceneMain.prototype.showError = function (caller, msg, buttons)
{
    if (typeof $.sfScene.get("Error").options == "undefined")
    {
        $.sfScene.get("Error").options = new Object();
    }
    
    if (!$.sfScene.get("Error").isShown)
    {
    	$.sfScene.get("Error").options.caller = caller;
    	$.sfScene.get("Error").options.popupMsg = msg;
    	$.sfScene.get("Error").options.buttons = buttons;
    
    	$.sfScene.show("Error");
    	$.sfScene.focus("Error");
    }
};

SceneMain.prototype.getCurrentScene = function ()
{
	return this.currentScene;
};

SceneMain.prototype.goBack = function ()
{
    if (this.prevScene.length > 0)
    {
        this.sendRequestForData(this.prevScene.pop());
    }
    else
    {
        $.sf.exit (false);
    }
};

SceneMain.prototype.clearHistory = function ()
{
	this.prevScene = [];
};

SceneMain.prototype.helpBar = function (params)
{
	var temp = {};
	var self = this;
	
	function formatPacketTime(packet, packet_name)
	{
		var ret = "";
		
		if (packet.days > 0)
		{
			ret = "Pakiet " + packet_name + " ważny " + parseInt(packet.days+1) + " d".pluralize(parseInt(packet.days+1), "zień,ni");
		}
		else if (packet.days == 0)
		{
			if (packet.hours > 0)
			{
				ret = "Pakiet " + packet_name + " ważny " + packet.hours + " godzin".pluralize(packet.hours, "ę,y,");
			}
			else
			{
				ret = "Pakiet " + packet_name + " ważny " + packet.minutes + " minut".pluralize(packet.minutes, "ę,y,");
			}
		}
		else
		{
			ret = "Brak pakietu " + packet_name;
		}
		
		return ret;
	}
	
	function preparePacketInfo()
	{
		var info = "";
		
		
		if (self.isIplexPlusAvailable())
		{
			info = formatPacketTime(self.getUser().iplex_plus, "iplex plus");
		}
		else if (self.isIplexZeroAvailable())
		{
			info = formatPacketTime(self.getUser().iplex_zero, "iplex zero");
		}
		else
		{
			info = "Brak pakietu";
		}
		
		return info;
	}
	
	if (this.isUserLogged())
	{
		temp["user"] = preparePacketInfo();
	}
	else
	{
		temp["user"] = "Użytkownik niezalogowany";
	}
	
    $("#helpBar").sfKeyHelp($.extend(temp, params));
};

SceneMain.prototype.getXHRObj = function (name)
{
    if (typeof name == "undefined")
    {
        return false;
    }
    
    if (typeof xhr[name] == "undefined")
    {
        xhr[name] = new XHRToolKit();
    }
    
    return xhr[name];
};

SceneMain.prototype.handleShow = function ()
{
	alert("SceneMain.handleShow()");
};

SceneMain.prototype.handleHide = function ()
{
	alert("SceneMain.handleHide()");
};

SceneMain.prototype.handleFocus = function ()
{
	alert("SceneMain.handleFocus()");
};

SceneMain.prototype.handleBlur = function ()
{
	alert("SceneMain.handleBlur()");
    
    $("#mainLoading").empty();
};

SceneMain.prototype.handleKeyDown = function (keyCode)
{
	alert("SceneMain.handleKeyDown(" + keyCode + ")");
    
	switch (keyCode)
    {
	    case 21:
	    	location.reload();
	    	break;
	    case $.sfKey.RETURN:
	        $.sfKey.block();
	        this.goBack();
	        break;
	}
};
