function ScenePlayer(options)
{
	this.options = options;
    this.selfState = {};
    this.gemiusMoviesStats = {};
    this.gemiusAdvertsStats = {};
    this.rightsUpdater = {};
    this.movieSeen = {};
    this.trackingCode = {};
    this.pluginAPI = null;
    this.tvKey = null;
}

ScenePlayer.prototype.initialize = function ()
{
	alert("ScenePlayer.initialize()");
    
    // prepeare to block SOURCE key
    this.pluginAPI = new Common.API.Plugin();
    this.tvKey = new Common.API.TVKeyValue(); // $.sfKey doesn't define SOURCE KEY ?!
    
    this.gemiusMoviesStats = new GemiusStats(conf.gemiusHitcollector, conf.gemiusMoviesIdentifier, conf.gemiusType, $.sfScene.get("Main").getXHRObj("GemiusMoviesStats"), conf.gemiusIplexPlusMoviesReportTimeout);
    this.gemiusAdvertsStats = new GemiusStats(conf.gemiusHitcollector, conf.gemiusAdvertsIdentifier, conf.gemiusType, $.sfScene.get("Main").getXHRObj("GemiusAdvertsStats"), 0);
    this.rightsUpdater = new RightsUpdater(conf.rightsUpdateURL, $.sfScene.get("Main").getXHRObj("RightsUpdater"));
    this.movieSeen = new MovieSeen(conf.movieSeenURL, $.sfScene.get("Main").getXHRObj("MovieSeen"));
    this.trackingCode = new TrackingCode($.sfScene.get("Main").getXHRObj("TrackingCode"));
    
	$("#videoController").sfVideo2_controller({});
    $("#videoComponent").sfVideo2(
    {
        idVideo2_controller: "videoController",
        lastMediaCallback: this.lastMedia,
        errorCallback: this.showError,
        statsController: {moviesStats: this.gemiusMoviesStats, advertsStats: this.gemiusAdvertsStats, trackingCode: this.trackingCode},
        rightsController: this.rightsUpdater,
        movieSeenController: this.movieSeen,
        videoDecryptKey: conf.videoDecryptKey,
        checkUserAccountDataCallback: this.checkUserAccountData,
        checkUserAccountDataCallbackInterval: conf.accountDataCheckInterval
    });
};

ScenePlayer.prototype.buildList = function (obj)
{
    if (obj.ERROR_CODE == "NOT_AUTHENTICATED")
    {
    	$.sfScene.get("Main").logoutUser();
        $.sfScene.get("Main").showError("NavigationMenuMovies", "Aby obejrzeć film musisz się zalogować oraz mieć aktywny pakiet iplex plus. Dowiedz się więcej o pakiecie iplex plus na <b>iplex.pl/iplexplus</b>. Czy chesz się teraz zalogować? [5x1x1]", {"login": true, "cancelAndReturn": true});
        return false;
    }
    
    if (obj.ERROR_CODE == "IPLEXPLUS_IS_NOT_ACTIVE")
    {
        $.sfScene.get("Main").showError("NavigationMenuMovies", "Aby obejrzeć film musisz mieć aktywny pakiet iplex plus. Dowiedz się więcej o pakiecie iplex plus na <b>iplex.pl/iplexplus</b>. [5x1x2]");
        return false;
    }    
    
    if (obj.type != "video")
    {
        $.sfScene.get("Main").showError("Player", "Przepraszamy, wystąpił błąd serwera [5x1x3].");
        return false;
    }
    
    $("#videoComponent").sfVideo2("play", {"movie": obj.movie, "adverts": obj.adverts});
};

ScenePlayer.prototype.sendRequestForData = function (obj)
{
    this.selfState = obj;
    var caller = this;
    
    playerXHR =  $.sfScene.get("Main").getXHRObj("Player");
    playerXHR.sendXHRRequest(this.selfState.url, function (result, respObj)
    {
        if (result)
        {
            caller.buildList($.parseJSON(respObj.responseText));
            return true;
        }
        else
        {
            $.sfScene.get("Main").showError("Player", "Przepraszamy, wystąpił błąd z połączeniem [5x0].<br />Prosimy spróbować ponownie za chwilę.");
            return false;
        }
    }, $.sfScene.get("Main").getUser().uuid);
};

ScenePlayer.prototype.lastMedia = function ()
{
    $.sfScene.get("Main").goBack();
};

ScenePlayer.prototype.showError = function (code, video_id, msg)
{
	if (!video_id)
	{
		video_id = "A0";
	}
    $.sfScene.get("Main").showError("Player", "Przepraszamy, wystąpił błąd odtwarzania [5x2x"+code+"x"+video_id+"].<br />"+msg);
};

ScenePlayer.prototype.checkUserAccountData = function (license)
{	
	var onAccountData = function (status)
	{
		if (status == "TRUE")
		{
			if (license == "PAID" && !$.sfScene.get("Main").isIplexPlusAvailable())
			{
				$("#videoComponent").sfVideo2("stop");
				$.sfScene.get("Main").showError("Player", "Twój pakiet iplex plus właśnie wygasł. Zapraszamy do zakupu nowej subskrypcji. [5x3]");
			}
		}
		else if (status == "FALSE" || status == "NOUSER") // on ERROR do nothing
		{
			$("#videoComponent").sfVideo2("stop");
			$.sfScene.get("Main").showError("Player", "Nastąpiło wylogowanie użytkownika. [5x4]");
		}
	};
	
	if ($.sfScene.get("Main").isIplexPlusAvailable())
	{
		$.sfScene.get("Main").getAccountData(onAccountData, false);
	}
};

ScenePlayer.prototype.handleShow = function ()
{
	alert("ScenePlayer.handleShow()");
    
    // block SOURCE key
    if (this.pluginAPI && this.tvKey)
    {
        this.pluginAPI.registKey(this.tvKey.KEY_SOURCE);
    }
};

ScenePlayer.prototype.handleHide = function ()
{
	alert("ScenePlayer.handleHide()");
    
    // unblock SOURCE key
    if (this.pluginAPI && this.tvKey)
    {
        this.pluginAPI.unregistKey(this.tvKey.KEY_SOURCE);
    }
    
    $.sfScene.get("Main").getXHRObj("Player").abortXHRObj();
};

ScenePlayer.prototype.handleFocus = function ()
{
	alert("ScenePlayer.handleFocus()");
    
    $("#videoComponent").sfVideo2("show");
};

ScenePlayer.prototype.handleBlur = function ()
{
	alert("ScenePlayer.handleBlur()");
};

ScenePlayer.prototype.handleKeyDown = function (keyCode)
{
	alert("ScenePlayer.handleKeyDown(" + keyCode + ")");
    
	switch (keyCode)
    {
        case $.sfKey.STOP:
        case $.sfKey.RETURN:
            $.sfKey.block();
            $("#videoComponent").sfVideo2("RCKeyDefined", keyCode);
            $.sfScene.get("Main").goBack();
            break;
            
        case $.sfKey.PLAY:
        case $.sfKey.PAUSE:
        case $.sfKey.RW:
        case $.sfKey.RW_:
        case $.sfKey.FF:
        case $.sfKey.FF_:
        case 1230: // BD forward button pressed
        case 1231: // BD rewind button pressed
        case 1232: // BD forward or rewind button released
        case $.sfKey.VOL_UP:
        case $.sfKey.VOL_DOWN:
        case $.sfKey.MUTE:
        case $.sfKey.INFO:
            $("#videoComponent").sfVideo2("RCKeyDefined", keyCode);
            break;
	}
};
